Command Aliases JSON Schema
---------------------------

```javascript
{
  "alias1": {"cmd": "alias {0}", "synopsis": "name"},
  "move": {"cmd": "move {0} {1}", "synypsis": "from to"}
}
```

Note, this indeed isn't a real JSON schema as defined by JSON-Schema.org (it doesn't support keys with random names).
